%global pkg_name parboiled
%{?scl:%scl_package %{pkg_name}}
%{?maven_find_provides_and_requires}

%global scala_short_version 2.10
%bcond_with    scala

Name:          %{?scl_prefix}%{pkg_name}
Version:       1.1.6
Release:       12%{?dist}.1
Summary:       Java/Scala library providing parsing of input text based on PEGs
License:       ASL 2.0
URL:           http://parboiled.org/
Source0:       https://github.com/sirthias/parboiled/archive/%{version}.tar.gz
# for build see https://github.com/sirthias/parboiled/wiki/Building-parboiled
Source1:       http://repo1.maven.org/maven2/org/parboiled/%{pkg_name}-core/%{version}/%{pkg_name}-core-%{version}.pom
Source2:       http://repo1.maven.org/maven2/org/parboiled/%{pkg_name}-java/%{version}/%{pkg_name}-java-%{version}.pom
# customized aggregator pom
Source3:       %{pkg_name}-pom.xml
Source4:       http://repo1.maven.org/maven2/org/parboiled/%{pkg_name}-scala_%{scala_short_version}/%{version}/%{pkg_name}-scala_%{scala_short_version}-%{version}.pom
Patch0:        %{pkg_name}-1.1.6-scala-use-antrun-plugin.patch
Patch1:        parboiled-port-to-objectweb-asm-5.0.1.patch

BuildRequires: %{?scl_prefix}maven-local
BuildRequires: %{?scl_prefix}mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: %{?scl_prefix}mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires: %{?scl_prefix}mvn(org.ow2.asm:asm)
BuildRequires: %{?scl_prefix}mvn(org.ow2.asm:asm-analysis)
BuildRequires: %{?scl_prefix}mvn(org.ow2.asm:asm-tree)
BuildRequires: %{?scl_prefix}mvn(org.ow2.asm:asm-util)
%if %{with scala}
BuildRequires: %{?scl_prefix}mvn(org.scala-lang:scala-compiler)
BuildRequires: %{?scl_prefix}mvn(org.scala-lang:scala-library)
%endif

%if 0
# test deps
BuildRequires: %{?scl_prefix}mvn(org.scalatest:scalatest_2.9.3)
BuildRequires: %{?scl_prefix}mvn(org.testng:testng)
%endif

BuildArch:     noarch

%description
parboiled is a mixed Java/Scala library providing for lightweight and
easy-to-use, yet powerful and elegant parsing of arbitrary input text
based on Parsing expression grammars (PEGs). PEGs are an alternative to
context free grammars (CFGs) for formally specifying syntax, they
make a good replacement for regular expressions and generally have quite
a few advantages over the "traditional" way of building parser via CFGs.

%if %{with scala}
%package scala
Summary:       Parboiled for Scala

%description scala
An internal Scala DSL for efficiently defining your parser rules.
%endif

%package javadoc
Summary:       Javadoc for %{pkg_name}

%description javadoc
This package contains javadoc for %{pkg_name}.

%prep
%setup -q -n %{pkg_name}-%{version}

find . -name "*.class" -delete
find . -name "*.jar" -delete

cp -p %{SOURCE1} %{pkg_name}-core/pom.xml
cp -p %{SOURCE2} %{pkg_name}-java/pom.xml
cp -p %{SOURCE4} %{pkg_name}-scala/pom.xml

%{?scl:scl enable %{scl} - <<"EOF"}
set -e -x
for m in core java; do
%pom_xpath_inject "pom:project" "
<build>
  <plugins>

  </plugins>
</build>" %{pkg_name}-${m}

%pom_add_plugin org.apache.maven.plugins:maven-jar-plugin %{pkg_name}-${m} "
<configuration>
  <archive>
    <manifestFile>\${project.build.outputDirectory}/META-INF/MANIFEST.MF</manifestFile>
  </archive>
</configuration>"
done

%pom_add_plugin org.apache.felix:maven-bundle-plugin %{pkg_name}-core "
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-SymbolicName>org.parboiled.core</Bundle-SymbolicName>
    <Bundle-Name>org.parboiled.core</Bundle-Name>
    <Bundle-Version>\${project.version}</Bundle-Version>
    <Private-Package>org.parboiled.core.*</Private-Package>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>"

%pom_add_plugin org.apache.felix:maven-bundle-plugin %{pkg_name}-java "
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-SymbolicName>org.parboiled.java</Bundle-SymbolicName>
    <Bundle-Name>org.parboiled.java</Bundle-Name>
    <Bundle-Version>\${project.version}</Bundle-Version>
    <Fragment-Host>org.parboiled.core</Fragment-Host>
    <Private-Package>org.parboiled.java.*</Private-Package>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>"

%patch0 -p0
%patch1 -p1

cp -p %{SOURCE3} pom.xml
sed -i "s|@VERSION@|%{version}|" pom.xml

%mvn_file :%{pkg_name}-core %{pkg_name}/core
%mvn_file :%{pkg_name}-java %{pkg_name}/java
%mvn_package :%{pkg_name}-project __noinstall
%if %{with scala}
%pom_xpath_inject "pom:modules" "<module>%{pkg_name}-scala</module>"
%mvn_file :%{pkg_name}-scala_%{scala_short_version} %{pkg_name}/scala
%mvn_package :%{pkg_name}-scala_%{scala_short_version} scala
%endif
%{?scl:EOF}

%build
%{?scl:scl enable %{scl} - <<"EOF"}
set -e -x
# test skipped unavailable dep org.scalatest scalatest_2.9.0 1.6.1
%mvn_build -f -- -Dproject.build.sourceEncoding=UTF-8
%{?scl:EOF}

%install
%{?scl:scl enable %{scl} - <<"EOF"}
set -e -x
%mvn_install
%{?scl:EOF}

%files -f .mfiles
%doc CHANGELOG README.markdown
%license LICENSE

%if %{with scala}
%files scala -f .mfiles-scala
%license LICENSE
%endif

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.6-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.6-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jun 21 2016 gil cattaneo <puntogil@libero.it> 1.1.6-10
- add missing build requires

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.6-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.6-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 25 2015 gil cattaneo <puntogil@libero.it> 1.1.6-7
- drop ExcludeArch for ARM

* Thu May 21 2015 gil cattaneo <puntogil@libero.it> 1.1.6-6
- disable paraboiled-scala on ARM (rhbz#1223754)

* Wed Feb 11 2015 gil cattaneo <puntogil@libero.it> 1.1.6-5
- introduce license macro

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Mar 27 2014 Michal Srb <msrb@redhat.com> - 1.1.6-3
- Port to objectweb-asm 5.0.1

* Thu Mar 20 2014 gil cattaneo <puntogil@libero.it> 1.1.6-2
- add scala support

* Tue Nov 26 2013 gil cattaneo <puntogil@libero.it> 1.1.6-1
- update to 1.1.6 rhbz#1034875

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 03 2013 gil cattaneo <puntogil@libero.it> 1.0.2-5
- switch to XMvn
- minor changes to adapt to current guideline

* Wed Feb 06 2013 Java SIG <java-devel@lists.fedoraproject.org> - 1.0.2-4
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Tue Feb 05 2013 gil cattaneo <puntogil@libero.it> 1.0.2-3
- fix unowned directory rhbz#907517

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 12 2012 gil cattaneo <puntogil@libero.it> 1.0.2-1
- initial rpm
